@@ -2,8 +2,8 @@ use strict;
 use warnings;
 
 package Net::FreshBooks::API::Recurring;
-BEGIN {
-  $Net::FreshBooks::API::Recurring::VERSION = '0.21';
+{
+  $Net::FreshBooks::API::Recurring::VERSION = '0.22';
 }
 
 use Moose;
@@ -92,7 +92,7 @@ Net::FreshBooks::API::Recurring - FreshBooks Recurring Item access
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
@@ -125,7 +125,16 @@ version 0.21
         tax1_name    => "GST",
         tax1_percent => 5,
     });
-
+    
+    # set up autobill
+    
+    my $autobill = Net::FreshBooks::API::Recurring::AutoBill->new;
+    $autobill->gateway_name('PayPal Payflow Pro');
+    $autobill->card->name('Tim Toady');
+    $autobill->card->number('4111 1111 1111 1111');
+    $autobill->card->expiration->month(12);
+    $autobill->card->expiration->year(2015);
+    
     # use the client object from the previous example
 
     my $recurring_item = $fb->recurring->create({
@@ -133,6 +142,7 @@ version 0.21
         date        => DateTime->now->add( days => 2 )->ymd, # YYYY-MM-DD
         frequency   => 'monthly',
         lines       => [ $line ],
+        autobill    => $autobill,
         notes       => 'Created by Net::FreshBooks::API',
     });
 
@@ -176,12 +186,18 @@ Returns a L<Net::FreshBooks::API::Recurring::AutoBill> object
     
     $recurring_item->create;
 
+To delete an autobill profile, just set autobill to an empty string prior
+to update.
+
+    $referring->autobill('');
+    $referring->update;
+
 =head2 list
 
 Returns a L<Net::FreshBooks::API::Iterator> object.
 
     my $recurrings = $fb->recurring->list;
-    while ( my $recurring = $recurrings->list ) {
+    while ( my $recurring = $recurrings->next ) {
         print $recurring->recurring_id, "\n";
     }
 
